diff -Naur awstats-6.9-orig/docs/awstats_faq.html awstats-6.9/docs/awstats_faq.html
--- awstats-6.9-orig/docs/awstats_faq.html	2008-04-27 18:47:02.000000000 +0200
+++ awstats-6.9/docs/awstats_faq.html	2008-08-20 19:00:58.000000000 +0200
@@ -800,7 +800,7 @@
 <b>
 sharedscripts<br>
 prerotate<br>
-/usr/local/awstats/wwwroot/cgi-bin/awstats.pl -update -config=mydomainconfig<br>
+/usr/lib/awstats/wwwroot/cgi-bin/awstats.pl -update -config=mydomainconfig<br>
 endscript<br>
 </b>
 postrotate<br>
@@ -905,11 +905,11 @@
 This is examples of lines you can add in the cron file (see your unix reference manual for cron) :<br>
 To run update every day at 03:50, use :<br>
 <table border=1 cellpadding=1 cellspacing=0 bgcolor=#F4F4F4 width="95%" class=CFAQ><tr class=CFAQ><td class=CFAQ>
-50 3 * * * /usr/local/awstats/wwwroot/cgi-bin/awstats.pl -config=mysite -update >/dev/null<br>
+50 3 * * * /usr/lib/awstats/wwwroot/cgi-bin/awstats.pl -config=mysite -update >/dev/null<br>
 </td></tr></table>
 To run update every hour, use :<br>
 <table border=1 cellpadding=1 cellspacing=0 bgcolor=#F4F4F4 width="95%" class=CFAQ><tr class=CFAQ><td class=CFAQ>
-0 * * * * /usr/local/awstats/wwwroot/cgi-bin/awstats.pl -config=mysite -update >/dev/null<br>
+0 * * * * /usr/lib/awstats/wwwroot/cgi-bin/awstats.pl -config=mysite -update >/dev/null<br>
 </td></tr></table>
 <br>
 
diff -Naur awstats-6.9-orig/docs/awstats_setup.html awstats-6.9/docs/awstats_setup.html
--- awstats-6.9-orig/docs/awstats_setup.html	2008-04-27 18:47:06.000000000 +0200
+++ awstats-6.9/docs/awstats_setup.html	2008-08-20 19:01:26.000000000 +0200
@@ -102,23 +102,23 @@
   <br>
 B) awstats_configure.pl will then add, if not already present, the
 following directives to your Apache configuration file
-(note that the "/usr/local/awstats/wwwroot" path might differ according
+(note that the "/usr/lib/awstats/wwwroot" path might differ according
 to your distribution or OS:<br>
   <i> <br>
 # <br>
 # Directives to add to your Apache conf file to allow use of AWStats as
 a CGI. <br>
-# Note that path "/usr/local/awstats/" must reflect your AWStats
+# Note that path "/usr/lib/awstats/" must reflect your AWStats
 Installation path. <br>
 # <br>
-Alias /awstatsclasses "/usr/local/awstats/wwwroot/classes/" <br>
-Alias /awstatscss "/usr/local/awstats/wwwroot/css/" <br>
-Alias /awstatsicons "/usr/local/awstats/wwwroot/icon/" <br>
-ScriptAlias /awstats/ "/usr/local/awstats/wwwroot/cgi-bin/" <br>
+Alias /awstatsclasses "/usr/lib/awstats/wwwroot/classes/" <br>
+Alias /awstatscss "/usr/lib/awstats/wwwroot/css/" <br>
+Alias /awstatsicons "/usr/lib/awstats/wwwroot/icon/" <br>
+ScriptAlias /awstats/ "/usr/lib/awstats/wwwroot/cgi-bin/" <br>
 # <br>
 # This is to permit URL access to scripts/files in AWStats directory. <br>
 # <br>
-&lt;Directory "/usr/local/awstats/wwwroot"&gt; <br>
+&lt;Directory "/usr/lib/awstats/wwwroot"&gt; <br>
 Options None <br>
 AllowOverride None <br>
 Order allow,deny <br>
diff -Naur awstats-6.9-orig/docs/awstats_webmin.html awstats-6.9/docs/awstats_webmin.html
--- awstats-6.9-orig/docs/awstats_webmin.html	2008-04-27 18:47:08.000000000 +0200
+++ awstats-6.9/docs/awstats_webmin.html	2008-08-20 19:01:34.000000000 +0200
@@ -59,7 +59,7 @@
 <li> You must now enter here values for:<br>
 - Absolute filesystem path to AWStats (CLI)<br>   
 It's the full path of the <i>awstats.pl</i> script. Path depends on package you use.<br>
-It could be <i>/usr/local/awstats/wwwroot/cgi-bin/awstats.pl</i><br>
+It could be <i>/usr/lib/awstats/wwwroot/cgi-bin/awstats.pl</i><br>
 - Absolute or relative URL path to AWStats (CGI)<br>
 It's absolute or relative URL you must enter to run AWStats as a CGI. This depends on the way
 you setup your web server and cgi directories.<br>
diff -Naur awstats-6.9-orig/tools/awstats_configure.pl awstats-6.9/tools/awstats_configure.pl
--- awstats-6.9-orig/tools/awstats_configure.pl	2008-04-06 15:45:24.000000000 +0200
+++ awstats-6.9/tools/awstats_configure.pl	2008-08-20 18:45:09.000000000 +0200
@@ -29,10 +29,10 @@
 $AWSTATS_DIRDATA_PATH
 /;
 $AWSTATS_PATH='';
-$AWSTATS_ICON_PATH='/usr/local/awstats/wwwroot/icon';
-$AWSTATS_CSS_PATH='/usr/local/awstats/wwwroot/css';
-$AWSTATS_CLASSES_PATH='/usr/local/awstats/wwwroot/classes';
-$AWSTATS_CGI_PATH='/usr/local/awstats/wwwroot/cgi-bin';
+$AWSTATS_ICON_PATH='/usr/lib/awstats/wwwroot/icon';
+$AWSTATS_CSS_PATH='/usr/lib/awstats/wwwroot/css';
+$AWSTATS_CLASSES_PATH='/usr/lib/awstats/wwwroot/classes';
+$AWSTATS_CGI_PATH='/usr/lib/awstats/wwwroot/cgi-bin';
 $AWSTATS_MODEL_CONFIG='/etc/awstats/awstats.model.conf';		# Used only when configure ran on linux
 $AWSTATS_DIRDATA_PATH='/var/lib/awstats';						# Used only when configure ran on linux
 
@@ -61,7 +61,7 @@
 'C:/Program Files/Apache Group/Apache2/conf/httpd.conf',
 'C:/Program Files/Apache Group/Apache/conf/httpd.conf',
 '/Applications/MAMP/conf/apache/httpd.conf',
-'/etc/httpd/httpd.conf',
+'/etc/httpd/conf/httpd.conf',
 '/usr/local/apache/conf/httpd.conf',
 '/usr/local/apache2/conf/httpd.conf',
 );
@@ -309,13 +309,13 @@
 	$AWSTATS_PATH=`pwd`; $AWSTATS_PATH =~ s/[\r\n]//;
 	$AWSTATS_PATH=~s/tools[\\\/]?$//;
 	$AWSTATS_PATH=~s/[\\\/]$//;
-	if ($AWSTATS_PATH ne '/usr/local/awstats') {
-		print "Warning: AWStats standard directory on Linux OS is '/usr/local/awstats'.\n";
+	if ($AWSTATS_PATH ne '/usr/lib/awstats') {
+		print "Warning: AWStats standard directory on Linux OS is '/usr/lib/awstats'.\n";
 		print "If you want to use standard directory, you should first move all content\n";
 		print "of AWStats distribution from current directory:\n";
 		print "$AWSTATS_PATH\n";
 		print "to standard directory:\n";
-		print "/usr/local/awstats\n";
+		print "/usr/lib/awstats\n";
 		print "And then, run configure.pl from this location.\n";
 		print "Do you want to continue setup from this NON standard directory [yN] ? ";
 		my $bidon='';
@@ -419,7 +419,7 @@
 		if ($bidon) { $ApachePath{"$bidon"}=1; }
 
 		print "\n".($bidon?"Now, enter":"Enter")." full config file path of your Web server.\n";
-		print "Example: /etc/httpd/httpd.conf\n";
+		print "Example: /etc/httpd/conf/httpd.conf\n";
 		print "Example: /usr/local/apache2/conf/httpd.conf\n";
 		print "Example: c:\\Program files\\apache group\\apache\\conf\\httpd.conf\n";
 		$bidon='';
diff -Naur awstats-6.9-orig/tools/awstats_updateall.pl awstats-6.9/tools/awstats_updateall.pl
--- awstats-6.9-orig/tools/awstats_updateall.pl	2006-07-24 00:57:48.000000000 +0200
+++ awstats-6.9/tools/awstats_updateall.pl	2008-08-20 18:45:33.000000000 +0200
@@ -130,8 +130,8 @@
 	# Check if AWSTATS prog is found
 	my $AwstatsFound=0;
 	if (-s "$Awstats") { $AwstatsFound=1; }
-	elsif (-s "/usr/local/awstats/wwwroot/cgi-bin/awstats.pl") {
-		$Awstats="/usr/local/awstats/wwwroot/cgi-bin/awstats.pl";
+	elsif (-s "/usr/lib/awstats/wwwroot/cgi-bin/awstats.pl") {
+		$Awstats="/usr/lib/awstats/wwwroot/cgi-bin/awstats.pl";
 		$AwstatsFound=1;
 	}
 	if (! $AwstatsFound) {
diff -Naur awstats-6.9-orig/tools/httpd_conf awstats-6.9/tools/httpd_conf
--- awstats-6.9-orig/tools/httpd_conf	2006-07-23 00:08:08.000000000 +0200
+++ awstats-6.9/tools/httpd_conf	1970-01-01 01:00:00.000000000 +0100
@@ -1,23 +0,0 @@
-#
-# Content of this file, with correct values, can be automatically added to
-# your Apache server by using the AWStats configure.pl tool.
-#
-
-#
-# Directives to add to your Apache conf file to allow use of AWStats as a CGI.
-# Note that path "/usr/local/awstats/" must reflect your AWStats install path.
-#
-Alias /awstatsclasses "/usr/local/awstats/wwwroot/classes/"
-Alias /awstatscss "/usr/local/awstats/wwwroot/css/"
-Alias /awstatsicons "/usr/local/awstats/wwwroot/icon/"
-ScriptAlias /awstats/ "/usr/local/awstats/wwwroot/cgi-bin/"
-
-#
-# This is to permit URL access to scripts/files in AWStats directory.
-#
-<Directory "/usr/local/awstats/wwwroot">
-    Options None
-    AllowOverride None
-    Order allow,deny
-    Allow from all
-</Directory>
diff -Naur awstats-6.9-orig/wwwroot/cgi-bin/awstats.model.conf awstats-6.9/wwwroot/cgi-bin/awstats.model.conf
--- awstats-6.9-orig/wwwroot/cgi-bin/awstats.model.conf	2008-04-27 18:47:24.000000000 +0200
+++ awstats-6.9/wwwroot/cgi-bin/awstats.model.conf	2008-08-20 19:01:51.000000000 +0200
@@ -2,7 +2,7 @@
 #-----------------------------------------------------------------------------
 # Copy this file into awstats.www.mydomain.conf and edit this new config file
 # to setup AWStats (See documentation in docs/ directory).
-# The config file must be in /etc/awstats, /usr/local/etc/awstats or /etc (for
+# The config file must be in /etc/awstats, /usr/lib/etc/awstats or /etc (for
 # Unix/Linux) or same directory than awstats.pl (Windows, Mac, Unix/Linux...)
 # To include an environment variable in any parameter (AWStats will replace
 # it with its value when reading it), follow the example:
@@ -48,7 +48,7 @@
 # If there are several log files from load balancing servers :
 # Example: "/pathtotools/logresolvemerge.pl *.log |"
 #
-LogFile="/var/log/httpd/mylog.log"
+LogFile="/var/log/httpd/access_log"
 
 
 # Enter the log file type you want to analyze.
@@ -150,7 +150,7 @@
 # Example: "ftp.domain.com"
 # Example: "domain.com"
 #
-SiteDomain=""
+SiteDomain="localhost"
 
 
 # Enter here all other possible domain names, addresses or virtual host
@@ -200,7 +200,7 @@
 # Example: "C:/awstats_data_dir"
 # Default: "."          (means same directory as awstats.pl)
 #
-DirData="."
+DirData="/var/lib/awstats"
 
 
 # Relative or absolute web URL of your awstats cgi-bin directory.
diff -Naur awstats-6.9-orig/tools/awstats_buildstaticpages.pl awstats-6.9/tools/awstats_buildstaticpages.pl
--- awstats-6.9-orig/tools/awstats_buildstaticpages.pl	2008-04-27 18:47:20.000000000 +0200
+++ awstats-6.9/tools/awstats_buildstaticpages.pl	2008-08-20 18:42:36.000000000 +0200
@@ -131,13 +131,13 @@
 	# Check config file in common possible directories :
 	# Windows :                   				"$DIR" (same dir than awstats.pl)
 	# Standard, Mandrake and Debian package :	"/etc/awstats"
 	# Other possible directories :				"/usr/local/etc/awstats", "/etc"
 	# FHS standard, Suse package : 				"/etc/opt/awstats"
 	my $configdir=shift;
 	my @PossibleConfigDir=();
 
 	if ($configdir) { @PossibleConfigDir=("$configdir"); }
-	else { @PossibleConfigDir=("$AwstatsDir","$DIR","/etc/awstats","/usr/local/etc/awstats","/etc","/etc/opt/awstats"); }
+	else { @PossibleConfigDir=("$AwstatsDir","$DIR","/etc/awstats","/usr/lib/etc/awstats","/etc","/etc/opt/awstats"); }
 
 	# Open config file
 	$FileConfig=$FileSuffix='';
@@ -302,8 +302,8 @@
 # Check if AWSTATS prog is found
 my $AwstatsFound=0;
 if (-s "$Awstats") { $AwstatsFound=1; }
-elsif (-s "/usr/local/awstats/wwwroot/cgi-bin/awstats.pl") {
-	$Awstats="/usr/local/awstats/wwwroot/cgi-bin/awstats.pl";
+elsif (-s "/usr/lib/awstats/wwwroot/cgi-bin/awstats.pl") {
+	$Awstats="/usr/lib/awstats/wwwroot/cgi-bin/awstats.pl";
 	$AwstatsFound=1;
 }
 if (! $AwstatsFound) {
@@ -131,13 +131,13 @@
 	# Windows :                   				"$DIR" (same dir than awstats.pl)
 	# Standard, Mandrake and Debian package :	"/etc/awstats"
-	# Other possible directories :				"/usr/local/etc/awstats", "/etc"
+	# Other possible directories :				"/usr/lib/etc/awstats", "/etc"
 	# FHS standard, Suse package : 				"/etc/opt/awstats"
 	my $configdir=shift;
diff -Naur awstats-6.9-orig/wwwroot/cgi-bin/awstats.pl awstats-6.9/wwwroot/cgi-bin/awstats.pl
--- awstats-6.9-orig/wwwroot/cgi-bin/awstats.pl	2008-07-27 20:21:56.000000000 +0200
+++ awstats-6.9/wwwroot/cgi-bin/awstats.pl	2008-08-20 19:02:04.000000000 +0200
@@ -1148,7 +1148,7 @@
 	# Check config file in common possible directories :
 	# Windows :                   				"$DIR" (same dir than awstats.pl)
 	# Standard, Mandrake and Debian package :	"/etc/awstats"
 	# Other possible directories :				"/usr/local/etc/awstats", "/etc"
 	# FHS standard, Suse package : 				"/etc/opt/awstats"
 	my $configdir=shift;
 	my @PossibleConfigDir=();
@@ -1165,7 +1165,7 @@
 			@PossibleConfigDir=("$configdir");
 		#}
 	}
-	else { @PossibleConfigDir=("$DIR","/etc/awstats","/usr/local/etc/awstats","/etc","/etc/opt/awstats"); }
+	else { @PossibleConfigDir=("$DIR","/etc/awstats","/usr/lib/etc/awstats","/etc","/etc/opt/awstats"); }
 
 	# Open config file
 	$FileConfig=$FileSuffix='';
@@ -1962,7 +1962,7 @@
 	# Windows and standard package:        		"$DIR/plugins" (plugins in same dir than awstats.pl)
 	# Redhat :                                  "/usr/local/awstats/wwwroot/cgi-bin/plugins"
 	# Debian package :                    		"/usr/share/awstats/plugins"
-	my @PossiblePluginsDir=("$DIR/plugins","/usr/local/awstats/wwwroot/cgi-bin/plugins","/usr/share/awstats/plugins");
+	my @PossiblePluginsDir=("$DIR/plugins","/usr/lib/awstats/wwwroot/cgi-bin/plugins","/usr/share/awstats/plugins");
  	my %DirAddedInINC=();
 
 	#Removed for security reason
@@ -5742,7 +5742,7 @@
 	print "  First, $PROG tries to read $PROG.virtualhostname.conf as the config file.\n";
 	print "  If not found, $PROG tries to read $PROG.conf\n";
 	print "  Note 1: Config files ($PROG.virtualhostname.conf or $PROG.conf) must be\n";
-	print "   in /etc/awstats, /usr/local/etc/awstats, /etc or same directory than\n";
+	print "   in /etc/awstats, /usr/lib/etc/awstats, /etc or same directory than\n";
 	print "   awstats.pl script file.\n";
 	print "  Note 2: If AWSTATS_FORCE_CONFIG environment variable is defined, AWStats will\n";
 	print "   use it as the \"config\" value, whatever is the value on command line or URL.\n";
@@ -1148,7 +1148,7 @@
 	# Windows :                   				"$DIR" (same dir than awstats.pl)
 	# Standard, Mandrake and Debian package :	"/etc/awstats"
-	# Other possible directories :				"/usr/local/etc/awstats", "/etc"
+	# Other possible directories :				"/usr/lib/etc/awstats", "/etc"
 	# FHS standard, Suse package : 				"/etc/opt/awstats"
 	my $configdir=shift;
